require "kemal"
require "redis"
require "sqlite3"
require "db"
require "http/client"

require "./config"
require "./handling"
require "./logger"
require "./utils/**"
require "./providers/**"

CONFIG   = Config.load
Kemal.config.port = CONFIG.port
Kemal.config.shutdown_message = false
Kemal.config.app_name = "vanity-tester-backend"
SQL = DB.open("sqlite3://#{CONFIG.db}")
REDIS_DB = Redis::Client.new(URI.parse("redis://#{CONFIG.redisUrl}"))
LOGGER = LogHandler.new(STDOUT, CONFIG.log_level)
REDIS_PREFIX = "vanity-tester-backend"

Utils.create_db

HEADERS = HTTP::Headers{"User-Agent" => "Vanity-Tester-Backend/0.1.0"}

before_get do |env|
  # Every response is a JSON
  env.response.content_type = "application/json"
  env.response.headers["Access-Control-Allow-Origin"] = "*"
end

get "/badges" do |env|
  if data = Utils::Redis.retrieveFromCache("badges")
    next data
  end
  data = Handlers.parse_badges(env)
  Utils::Redis.save("badges", data, CONFIG.key_expiration_time)
  data
end

get "/7tv/badges" do |env|
  if data = Utils::Redis.retrieveFromCache("7tvbadges")
    next data
  end
  data = Handlers.parse_7tv_badges(env)
  Utils::Redis.save("7tvbadges", data, CONFIG.key_expiration_time)
  data
end

get "/7tv/paints" do |env|
    if data = Utils::Redis.retrieveFromCache("7tvpaints")
    next data
  end
  data = Handlers.parse_7tv_paints(env)
  Utils::Redis.save("7tvpaints", data, CONFIG.key_expiration_time)
  data
end

get "/7tv/cosmetics/:user" do |env|
  Handlers.parse_7tv_user_cosmetics(env)
end

Kemal.run
